from setuptools import setup

with open('README.md', "r") as fh:
    long_description = fh.read()

setup(
    name = "mse-export-fixer",
    version = "1.0.3",
    author = "Brandon Lewis",
    description = "A command-line app for fixing the .xml files generated by the Magic Set Editor Cockatrice exporter.",
    long_description = long_description,
    long_description_content_type = "text/markdown",
    url = "https://github.com/brandazzle/mse-export-fixer",
    classifiers = [
        "Development Status :: 5 - Production/Stable",
        "Natural Language :: English",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",],
    scripts = ['fixer']
    )
